@@ -14,8 +14,10 @@ __all__ = [
 ]
 import json
 import logging
+import sys
 import urllib.parse as urlparse
 from io import BytesIO
+import platform
 from typing import List
 
 import requests
@@ -35,6 +37,7 @@ from .models import (
     Attr,
     YwhApiObject,
 )
+from .version import __VERSION__
 
 logger = logging.getLogger(__name__)
 
@@ -55,20 +58,39 @@ class YesWeHack(YwhApiObject):
         Attr(name='pat', type_=str, default=None),
     ]
 
-    def __init__(self, headers={}, totp_code=None, **kwargs):
+    def __init__(self, headers=None, totp_code=None, **kwargs):
         logging.basicConfig()
         super().__init__(**kwargs)
         logger.debug("init {0} on {1}".format(__name__, self.api_url))
 
         self.session = requests.session()
         self.session.verify = self.verify
-        self.session.headers = headers
+        self.session.headers = self._prepare_headers(headers or {})
         if self.pat:
             self.session.headers['X-AUTH-TOKEN'] = self.pat
 
         if not self.lazy and self.username != None and self.password != None:
             self.login(totp_code=totp_code)
 
+    def _prepare_headers(self, headers):
+        return self._prepare_user_agent(headers)
+
+    def _prepare_user_agent(self, headers):
+        existing_user_agent = None
+        for header, value in headers.copy().items():
+            if header.lower() == "user-agent":
+                del headers[header]
+                existing_user_agent = value
+                break
+        user_agent_parts = []
+        if existing_user_agent:
+            user_agent_parts.append(existing_user_agent)
+        user_agent_parts.append(f"yeswehack/{__VERSION__}")
+        user_agent_parts.append(f"python/{'.'.join(map(str, sys.version_info[:3]))}")
+        user_agent_parts.append(f"platform/{platform.platform()}")
+        headers["User-Agent"] = " ".join(user_agent_parts)
+        return headers
+
     def call(self, method, path, data=None):
         logger.debug("Calling " + path)
         resp = self.session.request(
@@ -76,6 +98,7 @@ class YesWeHack(YwhApiObject):
             self.api_url + path,
             data=data
         )
+
         try:
             json_resp = resp.json()
         except Exception as e:
@@ -200,10 +223,10 @@ class YesWeHack(YwhApiObject):
                 path += i + "=" + str(filters[i])
                 if count != len(filters):
                     path += "&"
-        resp_json = self.call("GET", path.format(page=1), data=filters)
+        resp_json = self.call("GET", path.format(page=1))
         reports += resp_json["items"]
         for i in range(1, resp_json["pagination"]["nb_pages"]):
-            resp_json = self.call("GET", path.format(page=i + 1), data=filters)
+            resp_json = self.call("GET", path.format(page=i + 1))
             reports += resp_json["items"]
         return [Report(self, lazy=lazy, **report) for report in reports]
 
@@ -351,6 +374,12 @@ class Log(YwhApiObject):
         Attr(name="tracker_url", type_=str, default=None),
         Attr(name="tracker_id", type_=str, default=None),
         Attr(name="tracker_token", type_=str, default=None),
+        Attr(name="new_ask_for_fix_verification_status", type_=str, default=None),
+        Attr(name="old_ask_for_fix_verification_status", type_=str, default=None),
+        Attr(name="program", type_=dict, default={}),
+        Attr(name="old_program", type_=dict, default={}),
+        Attr(name="new_triage_status", type_=str, default=None),
+        Attr(name="old_triage_status", type_=str, default=None),
     ]
 
     def __init__(self, ywh_api, lazy=False, **kwargs):
@@ -391,6 +420,7 @@ class Report(YwhApiObject):
         Attr(name="ywh_api", type_=YesWeHack),
         Attr(name="id", type_=int),
         Attr(name="application_finger_print", type_=str),
+        Attr(name="ask_for_fix_verification_status", type_=str),
         Attr(name="attachments", type_=list, default=[]),
         Attr(name="bonus", type_=int),
         Attr(name="bug_type", type_=BugType),
@@ -398,12 +428,14 @@ class Report(YwhApiObject):
         Attr(name="chainable_exploit_description_html", type_=str),
         Attr(name="chainable_report", type_=dict, default={}),
         Attr(name="created_at", type_=str),
+        Attr(name="cve", type_=dict, default={}),
         Attr(name="cvss", type_=CVSS),
         Attr(name="cvss_bonus", type_=int),
         Attr(name="description_html", type_=str, default=""),
         Attr(name="duplicate_of", type_=dict, default={}),
         Attr(name="end_point", type_=str),
         Attr(name="hunter", type_=dict, default={}),
+        Attr(name="impact", type_=str, default=""),
         Attr(name="local_id", type_=str),
         Attr(name="logs", type_=list),
         Attr(name="marked_as", type_=str),
@@ -598,6 +630,40 @@ class Report(YwhApiObject):
 
         return logs
 
+    def put_ask_for_fix_verification_status(self, status, message=None, attachments=None) -> List[Log]:
+        data = {
+            "status": status,
+            "attachments": attachments or [],
+        }
+        if message is not None:
+            data['message'] = message
+        http_response = self.ywh_api.raw_call(
+            method='PUT',
+            url=f'{self.ywh_api.api_url}/reports/{self.id}/ask-for-fix-verification-status-update',
+            data=json.dumps(data),
+            headers=self.ywh_api.apps_headers,
+        )
+        if not http_response.ok:
+            raise APIError(f'Unable to send report ask for fix verification status. Response: {http_response.text}')
+
+        try:
+            content = http_response.json()
+        except ValueError as e:
+            raise APIError(
+                f'Unable to parse response when sending report ask for fix verification status. Response: {http_response.text}'
+            ) from e
+
+        if not isinstance(content, dict) or 'items' not in content or not isinstance(content.get('items'), list):
+            raise APIError(
+                f'Unexpected response format when sending report ask for fix verification status. Response: {http_response.text}'
+            )
+
+        logs = []
+        for raw_log in content.get('items'):
+            logs.append(Log(ywh_api=self.ywh_api, **raw_log))
+
+        return logs
+
 
 
 class Program(YwhApiObject):
